about summary refs log tree commit diff
path: root/library/panic_unwind
diff options
context:
space:
mode:
authorRalf Jung <post@ralfj.de>2024-02-25 18:54:41 +0100
committerRalf Jung <post@ralfj.de>2024-02-26 11:10:18 +0100
commita3c0f3af9ca4247016eaaf476321d6ab95d5739e (patch)
treec6a361814998052dea01252a45f1048d9ccb8c4b /library/panic_unwind
parentb4ca582b8986c36d23726dc292c41b06fe7f9c6b (diff)
miri: rename miri_start_panic → miri_start_unwind
Diffstat (limited to 'library/panic_unwind')
-rw-r--r--library/panic_unwind/src/miri.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/library/panic_unwind/src/miri.rs b/library/panic_unwind/src/miri.rs
index d941b73b5fa..4d21e846010 100644
--- a/library/panic_unwind/src/miri.rs
+++ b/library/panic_unwind/src/miri.rs
@@ -8,14 +8,14 @@ type Payload = Box<Box<dyn Any + Send>>;
 
 extern "Rust" {
     /// Miri-provided extern function to begin unwinding.
-    fn miri_start_panic(payload: *mut u8) -> !;
+    fn miri_start_unwind(payload: *mut u8) -> !;
 }
 
 pub unsafe fn panic(payload: Box<dyn Any + Send>) -> u32 {
     // The payload we pass to `miri_start_panic` will be exactly the argument we get
     // in `cleanup` below. So we just box it up once, to get something pointer-sized.
     let payload_box: Payload = Box::new(payload);
-    miri_start_panic(Box::into_raw(payload_box) as *mut u8)
+    miri_start_unwind(Box::into_raw(payload_box) as *mut u8)
 }
 
 pub unsafe fn cleanup(payload_box: *mut u8) -> Box<dyn Any + Send> {
@@ -8,14 +8,14 @@ type Payload = Box<Box<dyn Any + Send>>;
 
 pub unsafe fn panic(payload: Box<dyn Any + Send>) -> u32 {
-    // The payload we pass to `miri_start_panic` will be exactly the argument we get
+    // The payload we pass to `miri_start_unwind` will be exactly the argument we get
     // in `cleanup` below. So we just box it up once, to get something pointer-sized.
     let payload_box: Payload = Box::new(payload);